"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StoplightElementsModule = void 0;
const handlebars = require("express-handlebars");
const path_1 = require("path");
const prependObjectIds = (d) => {
    const newD = d;
    Object.keys(d.paths).forEach(key => {
        Object.keys(newD.paths[key]).forEach(k => {
            var _a;
            if (k === 'get' ||
                k === 'post' ||
                k === 'patch' ||
                k === 'delete' ||
                k === 'put') {
                const a = { summary: '', operationId: "'" };
                (newD.paths[key][k] || a).summary = (_a = newD.paths[key][k]) === null || _a === void 0 ? void 0 : _a.operationId;
                (newD.paths[key][k] || a).operationId = `${key}/${k}`;
            }
        });
    });
    return newD;
};
class StoplightElementsModule {
    /**
     *
     * @param app - Nest Application
     * @param document - Swagger Document object
     */
    constructor(app, document, options = {}) {
        this.app = app;
        this.document = document;
        this.options = options;
    }
    /**
     * Attach module to existing NestJS app
     * @param path path to mount the Stoplight frontend @example '/api'
     */
    async start(path = '/') {
        return await this.setup(path);
    }
    /**
     * Setup ReDoc frontend for express plattform
     * @param path - path to mount the ReDoc frontend
     */
    async setup(path) {
        const httpAdapter = this.app.getHttpAdapter();
        const hbs = handlebars.create({
            helpers: {
                toJSON: function (object) {
                    return JSON.stringify(object);
                },
            },
        });
        const renderData = {
            data: {
                ...this.options,
                document: JSON.stringify(prependObjectIds(this.document)),
            },
        };
        // this is our handlebars file path
        const stoplightFilePath = (0, path_1.join)(__dirname, '..', '..', 'views', 'stoplight.handlebars');
        // console.log(stoplightFilePath);
        // // get handlebars rendered HTML
        const stoplightHTML = await hbs.render(stoplightFilePath, renderData);
        // // Serve stoplight Frontend
        httpAdapter.get(path, async (req, res) => {
            const sendPage = () => {
                res.setHeader('Content-Security-Policy', "default-src * 'unsafe-inline' 'unsafe-eval'; script-src * 'unsafe-inline' 'unsafe-eval'; child-src * 'unsafe-inline' 'unsafe-eval' blob:; worker-src * 'unsafe-inline' 'unsafe-eval' blob:; connect-src * 'unsafe-inline'; img-src * data: blob: 'unsafe-inline'; frame-src *; style-src * 'unsafe-inline';");
                res.send(stoplightHTML);
            };
            sendPage();
        });
    }
}
exports.StoplightElementsModule = StoplightElementsModule;
//# sourceMappingURL=stoplight-module.js.map